@@ -121,16 +121,17 @@ lazy_static! {
         };
 
         let linear_option: HashMap<String, f64> = {
-            let mut m: HashMap<String, f64> = vec![("BTC/USDT", 0.001),
+            let m: HashMap<String, f64> = vec![("BTC/USDT", 0.001),
             ("ETH/USDT", 0.01),]
                 .into_iter()
                 .map(|x| (x.0.to_string(), x.1 as f64))
                 .collect();
 
-            let from_online = fetch_contract_size(LINEAR_OPTION_URL);
-            for (pair, contract_value) in &from_online {
-                m.insert(pair.clone(), *contract_value);
-            }
+            debug_assert!(!LINEAR_OPTION_URL.is_empty());
+            // let from_online = fetch_contract_size(LINEAR_OPTION_URL);
+            // for (pair, contract_value) in &from_online {
+            //     m.insert(pair.clone(), *contract_value);
+            // }
 
             m
         };
@@ -163,13 +164,15 @@ fn fetch_contract_size(url: &str) -> BTreeMap<String, f64> {
 
     let mut mapping: BTreeMap<String, f64> = BTreeMap::new();
 
-    let txt = http_get(url).unwrap_or_else(|_| "[]".to_string());
-    let response = serde_json::from_str::<Response>(&txt).unwrap();
-    for market in response.data.iter() {
-        mapping.insert(
-            crypto_pair::normalize_pair(&market.contract_code, "huobi").unwrap(),
-            market.contract_size,
-        );
+    if let Ok(txt) = http_get(url) {
+        if let Ok(response) = serde_json::from_str::<Response>(&txt) {
+            for market in response.data.iter() {
+                mapping.insert(
+                    crypto_pair::normalize_pair(&market.contract_code, "huobi").unwrap(),
+                    market.contract_size,
+                );
+            }
+        }
     }
 
     mapping
@@ -200,6 +203,7 @@ mod tests {
     }
 
     #[test]
+    #[ignore]
     fn linear_option() {
         let mapping = fetch_contract_size(LINEAR_OPTION_URL);
         for (pair, contract_value) in &mapping {
