@@ -145,13 +145,15 @@ fn fetch_linear_contract_sizes() -> BTreeMap<String, f64> {
 
     let mut mapping: BTreeMap<String, f64> = BTreeMap::new();
 
-    let txt = http_get("https://contract.mxc.com/api/v1/contract/detail").unwrap();
-    let resp = serde_json::from_str::<ResponseMsg>(&txt).unwrap();
-    for linear_market in resp.data.iter().filter(|x| x.settleCoin == x.quoteCoin) {
-        mapping.insert(
-            crypto_pair::normalize_pair(&linear_market.symbol, "mxc").unwrap(),
-            linear_market.contractSize,
-        );
+    if let Ok(txt) = http_get("https://contract.mxc.com/api/v1/contract/detail") {
+        if let Ok(resp) = serde_json::from_str::<ResponseMsg>(&txt) {
+            for linear_market in resp.data.iter().filter(|x| x.settleCoin == x.quoteCoin) {
+                mapping.insert(
+                    crypto_pair::normalize_pair(&linear_market.symbol, "mxc").unwrap(),
+                    linear_market.contractSize,
+                );
+            }
+        }
     }
 
     mapping
